;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "reaper" "20250123.619"
  "Interact with Harvest time tracking app."
  '((emacs "26.2"))
  :url "https://github.com/xendk/reaper"
  :commit "7515ef42e0bfb0fd45d2e283e654271fe20cf447"
  :revdesc "7515ef42e0bf"
  :keywords '("tools")
  :authors '(("Thomas Fini Hansen" . "xen@xen.dk"))
  :maintainers '(("Thomas Fini Hansen" . "xen@xen.dk")))
